@@ -520,7 +520,7 @@ class Time:
 """
 
     @staticmethod
-    def by_date(date) -> __class__:
+    def by_date(date):
         """Create a Time variable from a Date variable.
 
         :param date: A Date variable.
@@ -533,7 +533,7 @@ class Time:
             raise TypeError('A Date type variable is expected')
 
     @staticmethod
-    def by_datetime_date(date: datetime.date) -> __class__:
+    def by_datetime_date(date: datetime.date):
         """Create a Time variable from a datetime.date variable.
 
         :param date: A datetime.date variable.
@@ -542,7 +542,7 @@ class Time:
         return Time(date.year, date.month, date.day)
 
     @staticmethod
-    def by_datetime_time(date: datetime.time) -> __class__:
+    def by_datetime_time(date: datetime.time):
         """Create a Time variable from a datetime.time variable.
 
         :param date: A datetime.time variable.
@@ -552,7 +552,7 @@ class Time:
                     date.microsecond // 1000, date.microsecond % 1000)
 
     @staticmethod
-    def by_datetime_datetime(date: datetime.datetime) -> __class__:
+    def by_datetime_datetime(date: datetime.datetime):
         """Create a Time variable from a datetime.datetime variable.
 
         :param date: A datetime.datetime variable.
@@ -674,14 +674,14 @@ class Time:
             self._year -= self._month // -12
             self._month = self._month % -12
 
-    def __abs__(self) -> __class__:
+    def __abs__(self):
         """The absolute value."""
         if self.get('nanosecond') < 0:
             return -self
         else:
             return self
 
-    def __neg__(self) -> __class__:
+    def __neg__(self):
         """The opposite value."""
         return Time() - self
 
@@ -704,7 +704,7 @@ class Time:
 
         return this, that
 
-    def __add__(self, other) -> __class__:
+    def __add__(self, other):
         """Add other."""
         this, that = self._get_this_and_that(other)
         res = this + that
